# Fennet
Deep learning for multi-dimensional proteomics


# mhc

For development:
In linux, if you clone the project in local and work in conda virtual environment,
when encountering *ModuleNotFoundError: No module named 'fennet'*，
you can execute *export PYTHONPATH=$PYTHONPATH:/path/to/Fennet/* in terminal and retry fennet command line tools.
